# SCENE-RIR

The purpose of the package is to extract the room impulse response (RIR) from the recorded response signal of a proper excitation signal.
The new swept-sine measurement method [1] is applied. Both linear sweep, corresponding to a white spectrum noise signal, and sweep with its frequency increasing exponentially with time, corresponding to pink spectrum noise signal, are implemented. The exponential swept-sine production is based on Angelo Farina's methodology [2].

It is part of the  **Audio Simulation Module**, developed for the **"Searchable multi-dimensional data lakes, supporting Cognive film production & distribution, for the promotion of the EuropeaN Cultural HeritagE"** Horizon project, **SCENE** (2023-2025).

Copyright (C) 2025 Christos Sevastiadis

## Installation

Use `pip` to install **scene-rir**

```
pip install scene-rir
```
(Requires Python>=3.8)


## Installation verification
To check if the package was installed successfully, try:
```
python -c "import scene_rir.rir; help(scene_rir.rir)
```
If the **scene-rir** is installed, this command will print all of its help documentation
string.

## Examples of usage

Examples of usage can be found in the `examples` and `tests` directories of the
repository tree. There are Python scripts in `.py` files, and Jupyter notebooks in
`.ipynb` files. To execute the test `.ipynb` notebooks, the directory `input` with its
content should be downloaded, either. To execute the examples and the tests, some extra
packages should be installed, for example, the `matplotlib` package.

### Usage from the Comman Line 

#### Open a Terminal or Command Prompt
- **Windows**: Press `Win + R`, type `cmd`, and hit
`Enter`.
- **Mac/Linux**: Open the terminal from your applications menu or use `Ctrl + Alt + T`.

#### Use the following command to get help for the Command Line usage
```
python -m scene_rir.rir --help
```

## License: GNU GPL v3.0

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

## References

- [1]: International Organization for Standardization (2006). Acoustics — Application of new measurement methods in building and room acoustics (ISO Standard No. 18233). Retrieved from https://www.iso.org/standard/40408.html.
- [2]: Farina, A. (2000, February). Simultaneous measurement of impulse response and distortion with a swept-sine technique. In Audio Engineering Society Convention 108. Audio Engineering Society.
